@@ -21,8 +21,9 @@
 #define SIDEBARMODE_H
 
 #include "BaseMode.h"
-#include <QWidget>
 #include <KSelectionProxyModel>
+#include <QIcon>
+#include <QWidget>
 
 class ModuleView;
 class KAboutData;
@@ -30,8 +31,10 @@ class QModelIndex;
 class QAbstractItemView;
 class QAbstractItemModel;
 class QAction;
+class SidebarMode;
 
-class FocusHackWidget : public QWidget {
+class FocusHackWidget : public QWidget
+{
     Q_OBJECT
 public:
     explicit FocusHackWidget(QWidget *parent = nullptr);
@@ -46,20 +49,29 @@ class SubcategoryModel : public KSelectionProxyModel
 {
     Q_OBJECT
     Q_PROPERTY(QString title READ title NOTIFY titleChanged)
+    Q_PROPERTY(QIcon icon READ icon NOTIFY iconChanged)
+    Q_PROPERTY(bool categoryOwnedByKCM READ categoryOwnedByKCM NOTIFY categoryOwnedByKCMChanged)
 
 public:
-    explicit SubcategoryModel(QAbstractItemModel *parentModel, QObject *parent = nullptr);
+    explicit SubcategoryModel(QAbstractItemModel *parentModel, SidebarMode *parent = nullptr);
 
     QString title() const;
+    QIcon icon() const;
+    bool categoryOwnedByKCM() const;
 
     void setParentIndex(const QModelIndex &activeModule);
 
+    Q_INVOKABLE void loadParentCategoryModule();
+
 Q_SIGNALS:
     void titleChanged();
+    void iconChanged();
+    void categoryOwnedByKCMChanged();
 
 private:
+    SidebarMode *m_sidebarMode;
     QAbstractItemModel *m_parentModel;
-    QString m_title;
+    QPersistentModelIndex m_activeModuleIndex;
 };
 
 class SidebarMode : public BaseMode
@@ -77,15 +89,16 @@ class SidebarMode : public BaseMode
     Q_PROPERTY(bool actionMenuVisible READ actionMenuVisible NOTIFY actionMenuVisibleChanged)
     Q_PROPERTY(bool introPageVisible READ introPageVisible WRITE setIntroPageVisible NOTIFY introPageVisibleChanged)
     Q_PROPERTY(bool defaultsIndicatorsVisible READ defaultsIndicatorsVisible NOTIFY defaultsIndicatorsVisibleChanged)
+    Q_PROPERTY(qreal headerHeight READ headerHeight WRITE setHeaderHeight NOTIFY headerHeightChanged)
 
 public:
-    SidebarMode(QObject * parent, const QVariantList &args );
+    SidebarMode(QObject *parent, const QVariantList &args);
     ~SidebarMode() override;
-    QWidget * mainWidget() override;
+    QWidget *mainWidget() override;
     void initEvent() override;
     void giveFocus() override;
-    KAboutData * aboutData() override;
-    ModuleView * moduleView() const override;
+    KAboutData *aboutData() override;
+    ModuleView *moduleView() const override;
     void reloadStartupModule() override;
 
     QAbstractItemModel *categoryModel() const;
@@ -104,6 +117,9 @@ public:
     bool introPageVisible() const;
     void setIntroPageVisible(const bool &introPageVisible);
 
+    qreal headerHeight() const;
+    void setHeaderHeight(qreal height);
+
     bool defaultsIndicatorsVisible() const;
     Q_INVOKABLE void toggleDefaultsIndicatorsVisibility();
 
@@ -116,11 +132,11 @@ public:
     Q_INVOKABLE void hideMostUsedToolTip();
     Q_INVOKABLE void showActionMenu(const QPoint &position);
 
-    Q_INVOKABLE void loadModule(const QModelIndex& activeModule, const QStringList &args = QStringList());
+    Q_INVOKABLE void loadModule(const QModelIndex &activeModule, const QStringList &args = QStringList());
 
 protected:
-    QList<QAbstractItemView*> views() const override;
-    bool eventFilter(QObject* watched, QEvent* event) override;
+    QList<QAbstractItemView *> views() const override;
+    bool eventFilter(QObject *watched, QEvent *event) override;
 
 private Q_SLOTS:
     void moduleLoaded();
@@ -134,6 +150,7 @@ Q_SIGNALS:
     void widthChanged();
     void actionMenuVisibleChanged();
     void introPageVisibleChanged();
+    void headerHeightChanged();
     void defaultsIndicatorsVisibleChanged();
 
 private:
